function stdevDW()
%function to calculate the standard deviation between DWI volumes and b0
%volumes. Background information is available in the paper 
%Jacques-Donald Tournier, Susumu Mori, Alexander Leemans, Diffusion tensor imaging and beyond
%Magnetic Resonance in Medicine Volume 65, Issue 6, pages 1532?1556

%(c) Pim Pullens  -- Brain Innovation BV, Maastricht NL
%June 3, 2011
%http://support.brainvoyager.com

disp('Starting calculations..');

dmr=BVQXfile('*.dmr','Please select a DMR..');
disp(['Opened ', dmr.FileNameOnDisk]);
dwi=dmr.DWIData;
dwi=resolve(dwi);
dwi=double(dwi);
nrslices=size(dwi,3);
nrvols=size(dwi,4);
nrows=size(dwi,1);
ncols=size(dwi,2);

grad=dmr.GradientInformation;

if isempty(grad)==1,
    grb=BVQXfile('*.grb');
    grad=grb.Gradients;
end

%get the b0s
b0=find(sum(grad,2)==0);
b0s=dwi(:,:,:,b0);

%create mask
ret = input('Do you want to mask the data for visualization? [y/n]','s');

if ret == 'y',
maskData = dwi(:,:,1,b0(1));
threshold = 3*mean(mean(maskData(1:5,:)));
mask = dwi(:,:,:,b0(1)) > threshold;
else
    mask = ones(size(dwi(:,:,:,1)));
end

%get dw
dw=find(sum(grad,2)~=0);
dws=dwi(:,:,:,dw);

stdDW=zeros(nrows,ncols,nrslices);
stdb0=stdDW;

%1e=rij, 2e=col

for s=1:nrslices,
    slice=squeeze(dws(:,:,s,:));
    disp(['DW: processing slice ',num2str(s)]);
    for r=1:nrows,
        for c=1:ncols,
            stdDW(r,c,s)=std(slice(r,c,:));
        end
    end
end

stdDW = stdDW.*mask;

if length(b0)>1,
    for s=1:nrslices,
        slice=squeeze(b0s(:,:,s,:));
        disp(['b0: processing slice ',num2str(s)]);
        for r=1:nrows,
            for c=1:ncols,
                stdb0(r,c,s)=std(slice(r,c,:));
            end
        end
    end
    stdb0 = stdb0.*mask;
    
    map=BVQXfile('new:map');
    
    if size(dwi,3)>25,
        map.Map(26:nrslices)=map.Map(1);
    end
    map.NrOfSlices = nrslices;
    map.DimX = ncols;
    map.DimY = nrows;
    map.Type = 4;
    map.LowerThreshold=0.01;
    q=reshape(stdb0,1,[]);
    map.UpperThreshold=mean(q)+3*std(q);
    clear q;
    for s = 1:nrslices,
        map.Map(s).Number = s;
        map.Map(s).Data=single(stdb0(:,:,s));
    end
    filename=dmr.FilenameOnDisk;
    mapFilename=[strtok(filename,'.'),'_stdb0.map'];
    map.SaveAs(mapFilename);
    disp(['Std of b0 saved as',mapFilename]);
    clear map;
end

%put result in map
map=BVQXfile('new:map');

if size(dwi,3)>25,
    map.Map(26:nrslices)=map.Map(1);
end
map.NrOfSlices = nrslices;
map.DimX = ncols;
map.DimY = nrows;
map.Type = 4;
map.LowerThreshold=0.01;
q=reshape(stdDW,1,[]);
map.UpperThreshold=mean(q)+3*std(q);
clear q;
for s = 1:nrslices,
    map.Map(s).Number = s;
    map.Map(s).Data=single(stdDW(:,:,s));
end
filename=dmr.FilenameOnDisk;
mapFilename=[strtok(filename,'.'),'_stdDW.map'];
map.SaveAs(mapFilename);
disp(['Std of DW saved as',mapFilename]);
disp('Done.');

clear map;


